@@ -20,7 +20,10 @@ package
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.08826';
+our $VERSION = '0.08926';
+
+$VERSION =~ /([0-9]{2})$/;
+my $compat_version = $1;
 
 use strict;
 use warnings;
@@ -1042,6 +1045,7 @@ GetOptions(
     'cflags-only-other' => \my $PrintCflagsOnlyOther,
     'exists' => \my $PrintExists,
     'atleast-version=s' => \my $AtLeastVersion,
+    'atleast-pkgconfig-version=s' => \my $AtLeastPkgConfigVersion,
     'exact-version=s'   => \my $ExactVersion,
     'max-version=s'     => \my $MaxVersion,
 
@@ -1083,10 +1087,18 @@ if($GuessPaths) {
 }
 
 if($PrintAPIversion) {
-    print "0.26\n";
+    print '0.', $compat_version, "\n";
     exit(0);
 }
 
+if($AtLeastPkgConfigVersion) {
+    my($major,$minor,$patch) = split /\./, $AtLeastPkgConfigVersion;
+    exit 1 if $major > 0;
+    exit 1 if $minor > $compat_version;
+    exit 1 if $minor == $compat_version && $patch > 0;
+    exit 0;
+}
+
 if($PrintRealVersion) {
 
     printf STDOUT ("ppkg-config - cruftless pkg-config\n" .
